# eg.py
'''
eg code
'''

EG_VAR='ABCD'

def testFunction():
    ''' returns a test string '''
    return 'OK'

class Mh (object):
    ''' Eg class '''

    def runMh(self):
        ''' Eg class function '''
        print ('OK RUN')
        return 100


