# eg.py
'''
eg code
'''

EG_VAR='abcd'

def test():
    ''' returns a test string '''
    return 'ok'

class Mh (object):
    ''' eg class doc string '''
    def runMh(self):
        ''' doc string for member function '''
        print ('ok run')
        return 10

